Django CTF Platform - Settings Documentation
Environment Configuration
Required Environment Variables

    DJANGO_CTF_SECRET_KEY: Secret key for Django (default provided)

    DJANGO_CTF_ENCRYPTION_KEY: Encryption key (32 characters recommended, default provided)

    DJANGO_CTF_DEBUG: Debug mode ("true"/"false", defaults to true)

    DJANGO_CTF_ALLOWED_HOSTS: Comma-separated hostnames (default: "127.0.0.1")

    DJANGO_CTF_SITE_URL: Base site URL (default: "http://127.0.0.1:8080")

Database Configuration

PostgreSQL is configured by default with these environment variables:

    DJANGO_CTF_POSTGRESQL_NAME: Database name (default: "CTF")

    DJANGO_CTF_POSTGRESQL_USER: Database user (default: "postgres")

    DJANGO_CTF_POSTGRESQL_PASSWORD: Database password (default: "root")

    DJANGO_CTF_POSTGRESQL_HOST: Database host (default: "localhost")

    DJANGO_CTF_POSTGRESQL_PORT: Database port (default: 5432)

Key Features
Security Settings

    CSRF protection enabled with trusted origins

    Custom encryption key handling

    Debug mode configurable via environment variable

    Custom user model (users.User)

Installed Apps

    Admin interface with colorfield

    Core Django apps

    Custom apps: users, main, web_tasks

Static & Media Files

    Static files served from /static/

    Static root: BASE_DIR/static

    Additional static dir: static_dev

    Media files served from /media/

    Media root: BASE_DIR/media

Important Notes

    CSRF middleware is currently commented out (line 48)

    No password validators are configured (empty AUTH_PASSWORD_VALIDATORS)

    Uses UTC timezone by default

    Admin media prefix set to /static/admin/

Deployment Recommendations
Production Checklist

    Set DEBUG=False in environment

    Generate new secret and encryption keys

    Configure proper ALLOWED_HOSTS

    Set up proper database credentials

    Uncomment CSRF middleware

    Add password validators for production

Development Defaults

    Debug mode enabled

    SQLite available (commented out)

    Localhost settings preconfigured

    Default admin credentials should be changed

This configuration provides a flexible base for a CTF platform with user management and task functionality, while maintaining security through environment variable configuration.